@@ -16,18 +16,19 @@ OTHER DEALINGS IN THE SOFTWARE.
 
 """
 from typing import Dict, Any, List
+
 from .platform import PlatformInfo
+from .segment import CSGOSegment
 from .user import UserInfo
-from .segment import Segment
 
 
 class CSGOProfile:
     def __init__(self, data: Dict[str, Any]):
         segments = []
         for seg in data["segments"]:
-            segments.append(Segment(seg))
+            segments.append(CSGOSegment(seg))
 
         self.platform_info: PlatformInfo = PlatformInfo(data["platformInfo"])
         self.user_info: UserInfo = UserInfo(data["userInfo"])
-        self.segments: List[Segment] = segments
+        self.segments: List[CSGOSegment] = segments
         self.expiry_date: str = data["expiryDate"]
